@@ -8,11 +8,10 @@ from pathlib import Path
 from datetime import datetime
 import timeit
 from contextlib import redirect_stdout, redirect_stderr
-import os
 
-import qualys_etl.etld_lib.etld_lib_config as etld_lib_config
-import qualys_etl.etld_lib.etld_lib_credentials as etld_lib_credentials
-import qualys_etl.etld_lib.etld_lib_functions as etld_lib_functions
+from qualys_etl.etld_lib import etld_lib_config
+from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_functions
 
 global target_module_to_run
 global target_method_in_module_to_run
@@ -87,22 +86,34 @@ def etl_files_are_stalled():
     etl_files_max_time_exceeded_flag = True
     etl_files = Path(etl_dir_to_monitor).glob('**/*')
     vm_workflow = \
-        re.fullmatch(r"^.*(kb_etl_workflow|host_list_etl_workflow|host_list_detection_etl_workflow).*$",
+        re.fullmatch(r"^.*(knowledgebase_etl_workflow|host_list_etl_workflow|host_list_detection_etl_workflow).*$",
                      str(target_method_in_module_to_run))
     asset_inventory_workflow = \
         re.fullmatch(r"^.*(asset_inventory_etl_workflow).*$",
                      str(target_method_in_module_to_run))
-    if vm_workflow:
-        workflow_pattern = re.compile(r"^.*(/kb|/host_list).*$")
-    elif asset_inventory_workflow:
-        workflow_pattern = re.compile(r"^.*(/asset_inventory).*$")
-    else:
-        workflow_pattern = re.compile(r"^ERROR$")
-        etld_lib_functions.logger.error("Could not determine workflow type.")
-        etld_lib_functions.logger.error("Please investigate.")
-        exit(1)
+
+    was_workflow = \
+        re.fullmatch(r"^.*(was_etl_workflow).*$",
+                     str(target_method_in_module_to_run))
+
+    test_system_workflow = \
+        re.fullmatch(
+            r"^.*(test_system_etl_workflow).*$", str(target_method_in_module_to_run))
 
     try:
+        if vm_workflow:
+            workflow_pattern = re.compile(r"^.*(/knowledgebase|/kb|/host_list).*$")
+        elif asset_inventory_workflow:
+            workflow_pattern = re.compile(r"^.*(/asset_inventory).*$")
+        elif was_workflow:
+            workflow_pattern = re.compile(r"^.*(/was).*$")
+        elif test_system_workflow:
+            workflow_pattern = re.compile(r"^.*(/test_system|/knowledgebase|/kb|/host_list|asset_inventory/was).*$")
+        else:
+            etld_lib_functions.logger.error("Could not determine workflow type.")
+            etld_lib_functions.logger.error("Please investigate.")
+            raise Exception("Error determining workflow type")
+
         for etl_file_path in etl_files:
             if Path(etl_file_path).is_file():
                 workflow_pattern_match = re.fullmatch(workflow_pattern, str(Path(etl_file_path)))
@@ -119,7 +130,6 @@ def etl_files_are_stalled():
         etl_files_max_time_exceeded_flag = True
         etld_lib_functions.logger.error(f"Could not determine file paths for monitoring: {etl_dir_to_monitor}")
         etld_lib_functions.logger.error(f"Please investigate Error: {e}.")
-        exit(1)
 
     if etl_files_max_time_exceeded_flag:
         etld_lib_functions.logger.info(f"{str(target_method_in_module_to_run)} is stalled.")
