@@ -1,6 +1,6 @@
-import qualys_etl.etld_lib.etld_lib_config as etld_lib_config
-import qualys_etl.etld_lib.etld_lib_spawn_etl as etld_lib_spawn_etl
-import qualys_etl.etld_host_list_detection.etld_01_workflow_manager_host_list_detection as etl_host_list_detection
+from qualys_etl.etld_lib import etld_lib_config
+from qualys_etl.etld_lib import etld_lib_spawn_etl
+from qualys_etl.etld_host_list_detection import host_list_detection_02_workflow_manager as etl_host_list_detection
 
 global vm_workflow
 global asset_inventory_workflow
@@ -23,13 +23,13 @@ def workflows(workflow_list :list):
 
     if workflow_list.__contains__('host_list_etl_workflow'):
         host_list_workflow = True
-    if workflow_list.__contains__('kb_etl_workflow'):
+    if workflow_list.__contains__('knowledgebase_etl_workflow'):
         kb_workflow = True
     if workflow_list.__contains__('host_list_detection_etl_workflow'):
         vm_workflow = True
         # Ensure kb and hostlist are run through vm_workflow and not independently
         host_list_workflow = False
-        kb_workflow = False
+        knowledgebase_workflow = False
 
     if workflow_list.__contains__('asset_inventory_etl_workflow'):
         asset_inventory_workflow = True
